hotspot/test/testlibrary_tests/RandomGeneratorTest.java
changeset 30604 b8d532cb6420
parent 29678 dd2f3932c21e
child 31232 741963a4e59e
--- a/hotspot/test/testlibrary_tests/RandomGeneratorTest.java	Sat May 02 18:40:37 2015 -0700
+++ b/hotspot/test/testlibrary_tests/RandomGeneratorTest.java	Mon May 04 16:30:07 2015 +0200
@@ -32,14 +32,14 @@
  * @run driver RandomGeneratorTest DIFFERENT_SEED
  */
 
-import com.oracle.java.testlibrary.ProcessTools;
-import com.oracle.java.testlibrary.Utils;
+import jdk.test.lib.ProcessTools;
+import jdk.test.lib.Utils;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Random;
 
 /**
  * The test verifies correctness of work {@link com.oracle.java.testlibrary.Utils#getRandomInstance()}.
  * Test works in three modes: same seed provided, no seed provided and
  * different seed provided. In the first case the test expects that all random numbers
  * will be repeated in all next iterations. For other two modes test expects that
@@ -32,14 +32,14 @@
 
 /**
- * The test verifies correctness of work {@link com.oracle.java.testlibrary.Utils#getRandomInstance()}.
+ * The test verifies correctness of work {@link jdk.test.lib.Utils#getRandomInstance()}.
  * Test works in three modes: same seed provided, no seed provided and
  * different seed provided. In the first case the test expects that all random numbers